@@ -212,9 +212,8 @@ class bufferServer(Elem):
             if bottom < top:
                 break
             insert = str(b) + self._colorCode() + " " * ((lines * columns) - realLen)
-            line = '\u001b[{row};0H' + self._colorCode() + insert + '\u001b[0m'
-            print(line
-                  .format(row=bottom, message=b, width=columns, fg=self.color, bg=self.background), end="")
+            line = '\u001b[{row};0H'.format(row=bottom) + self._colorCode() + insert + '\u001b[0m'
+            print(line, end="")
             sys.stdout.flush()
 
 
@@ -303,8 +302,7 @@ class lineServer(Elem):
         message = self._renderPattern(self.pattern[:suffixStart])
         message = fillSpaces(message, columns - stringLen(suffixStr))
         print('\u001b[{line};0H{cc}{message}{suffix}\u001b[0m'
-              .format(message,
-                      line=self.top if self.top is not None else rows - max(1, self.bottom),
+              .format(line=self.top if self.top is not None else rows - max(1, self.bottom),
                       cc=colorCode(bg=self.background, fg=self.color),
                       message=message,
                       suffix=suffixStr), end="")
